#!/bin/bash

# define main function
MAIN_INSTALL="main_install"
MAIN_UPGRADE="main_upgrade"
MAIN_UNINST="main_uninst"
# define each page's name
PAGE_MARIADB5="page_mariadb5"
PAGE_MARIADB10="page_mariadb10"
PAGE_RESTORE="page_restore"
PAGE_UPGRADE_RESTRICTED="page_upgrade_restricted"
PAGE_DB="page_db"
PAGE_UNINST="page_uninst"
DEFAULT="enu"
# set out file name
OUTPUT_INSTALL="install_uifile"
OUTPUT_UPGRADE="upgrade_uifile"
OUTPUT_UNINST="uninstall_uifile"
INIT_DB_NAME="" # need to be overwrited
INIT_DB_USER="" # need to be overwrited
INFO_FILE="" # need to be overwrited
BACKUP_PATH="" # need to be overwrited
# here to define what page is necessary for each stage: install, upgrade, and uninstall
PAGE_INST="$PAGE_MARIADB5 $PAGE_RESTORE $PAGE_MARIADB10 $PAGE_DB $MAIN_INSTALL"
PAGE_UPGRADE="$PAGE_UPGRADE_RESTRICTED $PAGE_MARIADB5 $PAGE_MARIADB10 $PAGE_DB $MAIN_UPGRADE"
PAGE_UNINST="$PAGE_UNINST $MAIN_UNINST"
MIGRATE_DB_VERSION="-1"

MainCreate()
{
	local output="$1"
	local pages="$2"
	local main_function="$3"
	local lan
	for dir in lang/*; do
		lan=$(basename "$dir")
		cat "wizard_common" "wizard_customized" > "${output}_${lan}.sh"
		CustomWizCreate "${output}_${lan}.sh"
		cat "lang/$lan" $pages "$main_function" >> "${output}_${lan}.sh"
	done
	chmod +x "${output}"*.sh
	cp -a "${output}_${DEFAULT}.sh" "${output}.sh"
}

IsUpgradable()
{
	true
}

NeedMigrateDB()
{
	local version="$1"
	if [ -z "$version" ] || [ "$version" -le "$MIGRATE_DB_VERSION" ]; then
		return 0
	fi
	return 1
}

CustomHasRunWebsiteSetup()
{
	local path="$1"
	[ -s "$path/$CONF_FILE" ]
}

CustomWizCreate()
{
	:
}

CustomSetBackupPath()
{
	BACKUP_PATH="$(CustomGetBackupPkgPath)"
}

CustomMainInstall()
{
	:
}

CustomGetValueFromMetaFile()
{
	local key="$1"
	local backup_info="/var/packages/.$PKG_DIR.conf"
	local syno_conf="/var/packages/$PKG_NAME/synology.conf"
	local record_file=""

	if [ -s "$INFO_FILE" ]; then
		record_file="$INFO_FILE"
	elif [ -s "$backup_info" ]; then
		record_file="$backup_info"
	elif [ -s "$syno_conf" ]; then
		record_file="$syno_conf"
	fi
	get_key_value "$record_file" "$key"
}

CustomGetBackupPrefix()
{
	local backup_prefix="/$(readlink /var/services/web | cut -d/ -f2)/@appstore/.$PKG_DIR"
	echo "$backup_prefix"
}

CustomGetBackupPkgPath()
{
	local backup_pkg_path="$(CustomGetBackupPrefix)/$PKG_DIR"
	echo "$backup_pkg_path"
}

# we define pages in fuction not in global variables,
# because functions in wizard steps will be merged after calling MainCreate.
CustomSetPages()
{
	NEW_INSTALL_PAGES="$(PageM10),$(PageDB)"
	RESTORE_PAGES="$(PageRestore),$(PageM10),$(PageDB)"
	MIGRATE_PAGES="$(PageM5),$(PageRestore),$(PageM10),$(PageDB)"
}

CustomParseDBConf()
{
	:
}

CustomGetDBName()
{
	:
}

CustomGetDBUser()
{
	:
}

CustomGetDBPass()
{
	:
}

CustomPageActivate()
{
	:
}

quote_json() {
	sed -e 's|\\|\\\\|g' -e 's|\"|\\\"|g'
}

#!/bin/bash
# Copyright (c) 2000-2017 Synology Inc. All rights reserved.

PKG_NAME="Moodle"
PKG_DIR="moodle"
WEBSITE_ROOT="/var/services/web/$PKG_DIR"
CONF_FILE="config.php"
MIGRATE_DB_VERSION="0118"
PAGE_FOLDER="page_folder"
PAGE_INST="$PAGE_MARIADB5 $PAGE_RESTORE $PAGE_FOLDER $PAGE_MARIADB10 $PAGE_DB $MAIN_INSTALL"
INIT_DB_NAME="$PKG_DIR"
INIT_DB_USER="${PKG_DIR}_user"
INFO_FILE="/usr/syno/etc/packages/$PKG_NAME/$PKG_DIR.conf"

CustomGetValueFromMetaFile()
{
	local key="$1"
	local backup_info="/var/packages/.$PKG_NAME.conf"
	local syno_conf="/var/packages/$PKG_NAME/synology.conf"
	local record_file=""

	if [ -s "$INFO_FILE" ]; then
		record_file="$INFO_FILE"
	elif [ -s "$backup_info" ]; then
		record_file="$backup_info"
	elif [ -s "$syno_conf" ]; then
		record_file="$syno_conf"
	fi
	get_key_value "$record_file" "$key"
}
CustomGetBackupPkgPath()
{
	CustomGetValueFromMetaFile "x_dataroot_x"
}

CustomMainInstall()
{
	local old_conf_file=".synology_config.php"
	local data_root_path=$(CustomGetBackupPkgPath)
	local old_build_num=$(CustomGetValueFromMetaFile "version")

	if [ -z "$old_build_num" ] || [ "$old_build_num" -le 0109 ]; then
		sed -i "s/x_database_x=/db_name=/g" "/var/packages/.$PKG_NAME.conf"
	fi

	if [ -s "$data_root_path/$old_conf_file" ]; then
		mv "$data_root_path/$old_conf_file" "$data_root_path/$CONF_FILE"
	fi
}

CustomParseDBConf()
{
	local path="$1"
	local db_info="$2"
	local grep_info="$3"
	local info_output=$(CustomGetValueFromMetaFile "$db_info")
	[ -z "$info_output" -a -s "$path/$CONF_FILE" ] && info_output=$(grep "CFG->$grep_info" "$path/$CONF_FILE" | cut -d\' -f2)
	echo "$info_output"
}

CustomGetDBName()
{
	CustomParseDBConf "$1" "db_name" "dbname"
}

CustomGetDBUser()
{
	CustomParseDBConf "$1" "db_user" "dbuser"
}

CustomGetDBPass()
{
	CustomParseDBConf "$1" "db_pass" "dbpass"
}

CustomSetPages()
{
	MIGRATE_PAGES="$(PageM5),$(PageRestore),$(PageFolder),$(PageM10),$(PageDB)"
	RESTORE_PAGES="$(PageRestore),$(PageFolder),$(PageM10),$(PageDB)"
	NEW_INSTALL_PAGES="$(PageFolder),$(PageM10),$(PageDB)"
}

CustomPageActivate()
{
	cat << EOF
if (arguments[0].headline == \"${md_wizard_data_root_title}\") {
	data_root_textfield = null;
	$(FindObj "pkgwizard_dataroot" "data_root_textfield")
	if (restore) {
		folder_name = \"$(basename "$(CustomGetBackupPkgPath)")\";
	} else {
		folder_name = \"moodle_folder\";
	}
	data_root_textfield.setDisabled(restore);
	data_root_textfield.setValue(folder_name);
}
EOF
}
wizard_db_settings="Moodle adatbázis telepítése"
wizard_db_name_desc="Kérjük, adja meg az adatbázis nevét a Moodle-adatbázishoz. "
wizard_db_name_label="Adatbázis neve"
wizard_m10_desc="Adja meg a MariaDB 10 rendszergazdai hitelesítő adatait a(z) Moodle adatbázis beállításának folytatásához."
wizard_admin_acc="Fiók"
wizard_admin_pass="Jelszó"
wizard_set_db_desc="Ha meglévő/új adatokat szeretne használni, hozzon létre egy új exkluzív adatbázisfiókot a következőhöz: Moodle."
wizard_set_data_title="Beállítás Moodle"
wizard_found_backup="Válasszon egy módszert az adatok importálásához."
wizard_decide_restore="Moodle adatbázis már létezik.<br>Válasszon az alábbi műveletek közül:"
wizard_restore="Meglévő adatok használata"
wizard_create_new="Tiszta telepítés (A rendszer minden meglévő adatot, ideértve a konfigurációs fájlokat és az adatbázist eltávolít.)"
wizard_db_user_account_desc="Adatbázis-felhasználói fiók"
wizard_db_user_password_desc="Adatbázis-felhasználói jelszó"
wizard_migrate_note="A(z) Moodle legújabb verziója csak a MariaDB 10 programot támogatja.<br>A rendszer észlelt egy meglévő MariaDB 5 adatbázist.<br>A következő lépésben az adatbázist a MariaDB 5 alól áttelepítjük a MariaDB 10 alá.<br><br>A telepítés folytatásához adja meg a MariaDB 5 rendszergazdai hitelesítő adatait."
wizard_migrate_title="Moodle adatbázis áttelepítése"
wizard_remove_msql_title="Moodle–adatbázis eltávolítása"
wizard_remove_msql_desc="A(z) Moodle adatbázis eltávolításával az összes adatot is törli a rendszer."
wizard_msql_password_desc_remove="A Moodle-adatbázis eltávolításához adja meg az adatbázis-rendszergazdához tartozó bejelentkezési adatokat."
wizard_admin_acc="Fiók"
wizard_admin_pass="Jelszó"
wizard_unable_to_upgrade_title="Nem sikerült frissíteni erre a verzióra"
wizard_upgrade_from_prev_release_required_desc="Mielőtt frissítené a csomagot erre a verzióra, frissítse az <a href=\"{1}\" target=\"_blank\">előző verzióra</a>."
md_wizard_data_root_title="Adatmappa útvonalának megadása"
md_wizard_data_root_desc="A Moodle adatmappájának elérési útjaként adja meg egy megosztott mappa nevét (például share_name). Ha a megosztott mappa még nem létezik, a rendszer létrehozza."
md_wizard_data_root_label="Adatmappa útvonala"
wizard_folder_desc="A rendszer létrehoz egy ugyanilyen nevű megosztott mappát. Győződjön meg róla, hogy nincs-e más megosztott mappa ezen a néven."
share_name_is_reserved="Az ön által megadott megosztási név fenntartott név."
md_dataroot_exist="Már létezik azonos nevű megosztott mappa. Egy eltérő nevet írjon be."
PageUninst()
{
cat << EOF
{
	"step_title": "$wizard_remove_msql_title",
	"items": [{
		"type": "multiselect",
		"desc": "$wizard_remove_msql_desc",
		"subitems": [{
			"key": "pkgwizard_remove_mysql",
			"desc": "$wizard_remove_msql_title"
		}]
	}, {
		"type": "textfield",
		"desc": "$wizard_msql_password_desc_remove",
		"subitems": [{
			"key": "wizard_m10_acc",
			"desc": "$wizard_admin_acc",
			"defaultValue": "root"
		}]
	}, {
		"type": "password",
		"subitems": [{
			"indent": 1,
			"key": "wizard_m10_pass",
			"desc": "$wizard_admin_pass"
		}]
	}]
}
EOF
}
main()
{
	local uninst_page="$(PageUninst)"
	echo "[$uninst_page]" > "${SYNOPKG_TEMP_LOGFILE}"

	return 0
}

main "$@"
main()
{
	local uninst_page="$(PageUninst)"
	echo "[$uninst_page]" > "${SYNOPKG_TEMP_LOGFILE}"

	return 0
}

main "$@"
