#!/bin/bash

# define main function
MAIN_INSTALL="main_install"
MAIN_UPGRADE="main_upgrade"
MAIN_UNINST="main_uninst"
# define each page's name
PAGE_MARIADB5="page_mariadb5"
PAGE_MARIADB10="page_mariadb10"
PAGE_RESTORE="page_restore"
PAGE_UPGRADE_RESTRICTED="page_upgrade_restricted"
PAGE_DB="page_db"
PAGE_UNINST="page_uninst"
DEFAULT="enu"
# set out file name
OUTPUT_INSTALL="install_uifile"
OUTPUT_UPGRADE="upgrade_uifile"
OUTPUT_UNINST="uninstall_uifile"
INIT_DB_NAME="" # need to be overwrited
INIT_DB_USER="" # need to be overwrited
INFO_FILE="" # need to be overwrited
BACKUP_PATH="" # need to be overwrited
# here to define what page is necessary for each stage: install, upgrade, and uninstall
PAGE_INST="$PAGE_MARIADB5 $PAGE_RESTORE $PAGE_MARIADB10 $PAGE_DB $MAIN_INSTALL"
PAGE_UPGRADE="$PAGE_UPGRADE_RESTRICTED $PAGE_MARIADB5 $PAGE_MARIADB10 $PAGE_DB $MAIN_UPGRADE"
PAGE_UNINST="$PAGE_UNINST $MAIN_UNINST"
MIGRATE_DB_VERSION="-1"

MainCreate()
{
	local output="$1"
	local pages="$2"
	local main_function="$3"
	local lan
	for dir in lang/*; do
		lan=$(basename "$dir")
		cat "wizard_common" "wizard_customized" > "${output}_${lan}.sh"
		CustomWizCreate "${output}_${lan}.sh"
		cat "lang/$lan" $pages "$main_function" >> "${output}_${lan}.sh"
	done
	chmod +x "${output}"*.sh
	cp -a "${output}_${DEFAULT}.sh" "${output}.sh"
}

IsUpgradable()
{
	true
}

NeedMigrateDB()
{
	local version="$1"
	if [ -z "$version" ] || [ "$version" -le "$MIGRATE_DB_VERSION" ]; then
		return 0
	fi
	return 1
}

CustomHasRunWebsiteSetup()
{
	local path="$1"
	[ -s "$path/$CONF_FILE" ]
}

CustomWizCreate()
{
	:
}

CustomSetBackupPath()
{
	BACKUP_PATH="$(CustomGetBackupPkgPath)"
}

CustomMainInstall()
{
	:
}

CustomGetValueFromMetaFile()
{
	local key="$1"
	local backup_info="/var/packages/.$PKG_DIR.conf"
	local syno_conf="/var/packages/$PKG_NAME/synology.conf"
	local record_file=""

	if [ -s "$INFO_FILE" ]; then
		record_file="$INFO_FILE"
	elif [ -s "$backup_info" ]; then
		record_file="$backup_info"
	elif [ -s "$syno_conf" ]; then
		record_file="$syno_conf"
	fi
	get_key_value "$record_file" "$key"
}

CustomGetBackupPrefix()
{
	local backup_prefix="/$(readlink /var/services/web | cut -d/ -f2)/@appstore/.$PKG_DIR"
	echo "$backup_prefix"
}

CustomGetBackupPkgPath()
{
	local backup_pkg_path="$(CustomGetBackupPrefix)/$PKG_DIR"
	echo "$backup_pkg_path"
}

# we define pages in fuction not in global variables,
# because functions in wizard steps will be merged after calling MainCreate.
CustomSetPages()
{
	NEW_INSTALL_PAGES="$(PageM10),$(PageDB)"
	RESTORE_PAGES="$(PageRestore),$(PageM10),$(PageDB)"
	MIGRATE_PAGES="$(PageM5),$(PageRestore),$(PageM10),$(PageDB)"
}

CustomParseDBConf()
{
	:
}

CustomGetDBName()
{
	:
}

CustomGetDBUser()
{
	:
}

CustomGetDBPass()
{
	:
}

CustomPageActivate()
{
	:
}

quote_json() {
	sed -e 's|\\|\\\\|g' -e 's|\"|\\\"|g'
}

#!/bin/bash
# Copyright (c) 2000-2017 Synology Inc. All rights reserved.

PKG_NAME="Moodle"
PKG_DIR="moodle"
WEBSITE_ROOT="/var/services/web/$PKG_DIR"
CONF_FILE="config.php"
MIGRATE_DB_VERSION="0118"
PAGE_FOLDER="page_folder"
PAGE_INST="$PAGE_MARIADB5 $PAGE_RESTORE $PAGE_FOLDER $PAGE_MARIADB10 $PAGE_DB $MAIN_INSTALL"
INIT_DB_NAME="$PKG_DIR"
INIT_DB_USER="${PKG_DIR}_user"
INFO_FILE="/usr/syno/etc/packages/$PKG_NAME/$PKG_DIR.conf"

CustomGetValueFromMetaFile()
{
	local key="$1"
	local backup_info="/var/packages/.$PKG_NAME.conf"
	local syno_conf="/var/packages/$PKG_NAME/synology.conf"
	local record_file=""

	if [ -s "$INFO_FILE" ]; then
		record_file="$INFO_FILE"
	elif [ -s "$backup_info" ]; then
		record_file="$backup_info"
	elif [ -s "$syno_conf" ]; then
		record_file="$syno_conf"
	fi
	get_key_value "$record_file" "$key"
}
CustomGetBackupPkgPath()
{
	CustomGetValueFromMetaFile "x_dataroot_x"
}

CustomMainInstall()
{
	local old_conf_file=".synology_config.php"
	local data_root_path=$(CustomGetBackupPkgPath)
	local old_build_num=$(CustomGetValueFromMetaFile "version")

	if [ -z "$old_build_num" ] || [ "$old_build_num" -le 0109 ]; then
		sed -i "s/x_database_x=/db_name=/g" "/var/packages/.$PKG_NAME.conf"
	fi

	if [ -s "$data_root_path/$old_conf_file" ]; then
		mv "$data_root_path/$old_conf_file" "$data_root_path/$CONF_FILE"
	fi
}

CustomParseDBConf()
{
	local path="$1"
	local db_info="$2"
	local grep_info="$3"
	local info_output=$(CustomGetValueFromMetaFile "$db_info")
	[ -z "$info_output" -a -s "$path/$CONF_FILE" ] && info_output=$(grep "CFG->$grep_info" "$path/$CONF_FILE" | cut -d\' -f2)
	echo "$info_output"
}

CustomGetDBName()
{
	CustomParseDBConf "$1" "db_name" "dbname"
}

CustomGetDBUser()
{
	CustomParseDBConf "$1" "db_user" "dbuser"
}

CustomGetDBPass()
{
	CustomParseDBConf "$1" "db_pass" "dbpass"
}

CustomSetPages()
{
	MIGRATE_PAGES="$(PageM5),$(PageRestore),$(PageFolder),$(PageM10),$(PageDB)"
	RESTORE_PAGES="$(PageRestore),$(PageFolder),$(PageM10),$(PageDB)"
	NEW_INSTALL_PAGES="$(PageFolder),$(PageM10),$(PageDB)"
}

CustomPageActivate()
{
	cat << EOF
if (arguments[0].headline == \"${md_wizard_data_root_title}\") {
	data_root_textfield = null;
	$(FindObj "pkgwizard_dataroot" "data_root_textfield")
	if (restore) {
		folder_name = \"$(basename "$(CustomGetBackupPkgPath)")\";
	} else {
		folder_name = \"moodle_folder\";
	}
	data_root_textfield.setDisabled(restore);
	data_root_textfield.setValue(folder_name);
}
EOF
}
wizard_db_settings="Configurar base de dados do Moodle"
wizard_db_name_desc="Introduza o nome da base de dados para Moodle."
wizard_db_name_label="Nome da base de dados"
wizard_m10_desc="Introduza as credenciais do administrador de MariaDB 10 para continuar as definições da base de dados do Moodle."
wizard_admin_acc="Conta"
wizard_admin_pass="Palavra-passe"
wizard_set_db_desc="Crie uma nova conta de base de dados exclusiva para o Moodle para utilizar os dados existentes/novos."
wizard_set_data_title="Configurar Moodle"
wizard_found_backup="Selecione um método para importar dados."
wizard_decide_restore="Moodle a base de dados já existe.<br>Selecione uma das seguintes ações:"
wizard_restore="Utilizar os dados existentes"
wizard_create_new="Limpar a instalação (todos os dados existentes, incluindo os ficheiros de configuração e a base de dados, serão removidos.)"
wizard_db_user_account_desc="Conta de utilizador de base de dados "
wizard_db_user_password_desc="Palavra-passe do utilizador de base de dados"
wizard_migrate_note="A versão mais recente do Moodle só suporta MariaDB 10.<br>O sistema detetou uma base de dados MariaDB 5 existente.<br>No passo seguinte, a sua base de dados será migrada de MariaDB 5 para MariaDB 10.<br><br>Introduza as credenciais do administrador de MariaDB 5 para continuar com a instalação."
wizard_migrate_title="Migrar a base de dados da Moodle"
wizard_remove_msql_title="Remover base de dados Moodle"
wizard_remove_msql_desc="Se a base de dados do Moodle for removida, todos os dados serão eliminados."
wizard_msql_password_desc_remove="Introduza as credenciais de administrador de base de dados de forma a remover a base de dados Moodle."
wizard_admin_acc="Conta"
wizard_admin_pass="Palavra-passe"
wizard_unable_to_upgrade_title="Não foi possível atualizar para esta versão"
wizard_upgrade_from_prev_release_required_desc="Antes de atualizar o pacote para esta versão, atualize-o para a <a href=\"{1}\" target=\"_blank\">versão anterior</a>."
md_wizard_data_root_title="Introduza o caminho da pasta de dados"
md_wizard_data_root_desc="Introduza um nome de pasta partilhada para funcionar como caminho de pasta de dados (por ex., nome:partilha) de Moodle. Se a pasta partilhada não exisitir, será criada."
md_wizard_data_root_label="Caminho da pasta de dados"
wizard_folder_desc="O sistema criará um pasta partilhada com este nome. Certifique-se de que não existem outras pastas partilhadas com o mesmo nome."
share_name_is_reserved="O nome de partilha introduzido está reservado."
md_dataroot_exist="Já existe uma pasta partilhada com o mesmo nome. Introduza um nome diferente."
PageUninst()
{
cat << EOF
{
	"step_title": "$wizard_remove_msql_title",
	"items": [{
		"type": "multiselect",
		"desc": "$wizard_remove_msql_desc",
		"subitems": [{
			"key": "pkgwizard_remove_mysql",
			"desc": "$wizard_remove_msql_title"
		}]
	}, {
		"type": "textfield",
		"desc": "$wizard_msql_password_desc_remove",
		"subitems": [{
			"key": "wizard_m10_acc",
			"desc": "$wizard_admin_acc",
			"defaultValue": "root"
		}]
	}, {
		"type": "password",
		"subitems": [{
			"indent": 1,
			"key": "wizard_m10_pass",
			"desc": "$wizard_admin_pass"
		}]
	}]
}
EOF
}
main()
{
	local uninst_page="$(PageUninst)"
	echo "[$uninst_page]" > "${SYNOPKG_TEMP_LOGFILE}"

	return 0
}

main "$@"
main()
{
	local uninst_page="$(PageUninst)"
	echo "[$uninst_page]" > "${SYNOPKG_TEMP_LOGFILE}"

	return 0
}

main "$@"
